# Slot: mixins


List of definitions to be mixed in. Targets may be any definition of the same type

URI: [http://w3id.org/biolink/biolinkml/meta/slot_definition_mixins](slot_uri)
## Domain and Range

[SlotDefinition](SlotDefinition.md) -><sub>opt</sub> [[SlotDefinition](SlotDefinition.md)]
## Inheritance

 *  is_a: [mixins](mixins.md)
## Children

## Used by

 * [SlotDefinition](SlotDefinition.md)
